@@ -66,10 +66,10 @@ class Client(GoogleDatastoreClient):
         """ Convert recursively a dict to an excluded entity"""
         if isinstance(input_data, Dict) or isinstance(input_data, dict):
             entity = Entity(exclude_from_indexes=tuple(input_data.keys()))
-            entity.update({index: self.convert_dict_to_excluded_entity(value) for index, value in input_data.items()})
+            entity.update({index: self.convert_input_to_excluded_entity(value) for index, value in input_data.items()})
             return entity
         elif isinstance(input_data, list) or isinstance(input_data, tuple):
-            return [self.convert_dict_to_excluded_entity(elem) for elem in input_data]
+            return [self.convert_input_to_excluded_entity(elem) for elem in input_data]
         else:
             return input_data
 
